==> cloudt-boot-3.2.4.36-20230625.100044-1-sources.jar: com/elitescloud/boot/common/param/AbstractOrderQueryParam.java <==
package com.elitescloud.boot.common.param;

import com.elitescloud.cloudt.common.base.ApiCode;
import com.elitescloud.cloudt.common.base.param.OrderQueryParam;
import com.elitescloud.cloudt.common.exception.BusinessException;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.querydsl.core.types.Order;
import com.querydsl.core.types.OrderSpecifier;
import com.querydsl.core.types.dsl.EntityPathBase;
import com.querydsl.core.types.dsl.PathBuilder;
import com.querydsl.core.types.dsl.PathBuilderValidator;
import com.querydsl.jpa.impl.JPAQuery;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.val;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.stream.Collectors;

/**
 * 可排序查询参数对象
 *
 * @author Michael Li
 * @date 2019-08-04
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel("可排序查询参数对象")
public abstract class AbstractOrderQueryParam extends OrderQueryParam {
    private static final long serialVersionUID = 57714391204790143L;

    @JsonIgnore
    public PageRequest getPageRequest() {
        val orderBys = CollectionUtils.isEmpty(getOrders()) ? new ArrayList<Sort.Order>() :
                getOrders().stream().filter(t -> StringUtils.hasText(t.getColumn())).map(o -> new Sort.Order(
                        o.isAsc() ? Sort.Direction.ASC : Sort.Direction.DESC,
                        o.getColumn()
                )).collect(Collectors.toList());

        return PageRequest.of(getCurrent(), getSize(), Sort.by(orderBys));
    }

    /**
     * 单表查询,排序方法
     *
     * @param query
     * @param entityPathBase 实体对象
     */
    @JsonIgnore
    public void fillOrders(JPAQuery<?> query, EntityPathBase<?> entityPathBase) {
        val pageRequest = getPageRequest();
        val orderbyExpr = new PathBuilder<>(entityPathBase.getClass(),
                entityPathBase.getMetadata(), PathBuilderValidator.FIELDS);
        pageRequest.getSort().forEach(s -> query.orderBy(
                new OrderSpecifier(
                        s.isAscending() ? Order.ASC : Order.DESC,
                        orderbyExpr.get(s.getProperty())
                )
        ));
    }

    /**
     * 多表关联查询，排序方法。要求：排序字段格式需为 “实体对象名称.字段名称”
     *
     * @param query
     */
    @JsonIgnore
    public void fillOrders(JPAQuery<?> query) {
        val pageRequest = getPageRequest();
        pageRequest.getSort().forEach(s -> {
            val sects = s.getProperty().split("\\.");
            if (sects.length > 1) {
                val orderbyExpr = new PathBuilder<>(Object.class, sects[0]);
                query.orderBy(new OrderSpecifier(s.isAscending() ?
                        Order.ASC : Order.DESC, orderbyExpr.get(sects[1])));
            } else {
                throw new BusinessException(ApiCode.PARAMETER_PARSE_EXCEPTION, "排序字段需要指定所属hql的实体对象，对象名称.字段名称");
            }
        });
    }

    @JsonIgnore
    public void setPaging(JPAQuery<?> query) {
        query.offset((long) getCurrent() * getSize());
        query.limit(getSize());
    }
}

==> cloudt-boot-3.3.26.6-0614-20240620.050854-1-sources.jar: com/elitescloud/boot/common/param/AbstractOrderQueryParam.java <==
package com.elitescloud.boot.common.param;

import com.elitescloud.boot.exception.BusinessException;
import com.elitescloud.cloudt.common.base.ApiCode;
import com.elitescloud.cloudt.common.base.param.OrderQueryParam;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.querydsl.core.types.Order;
import com.querydsl.core.types.OrderSpecifier;
import com.querydsl.core.types.dsl.EntityPathBase;
import com.querydsl.core.types.dsl.PathBuilder;
import com.querydsl.core.types.dsl.PathBuilderValidator;
import com.querydsl.jpa.impl.JPAQuery;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.val;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.stream.Collectors;

/**
 * 可排序查询参数对象
 *
 * @author Michael Li
 * @date 2019-08-04
 */
@Data
@EqualsAndHashCode(callSuper = true)
@ApiModel("可排序查询参数对象")
public abstract class AbstractOrderQueryParam extends OrderQueryParam {
    private static final long serialVersionUID = 57714391204790143L;

    @JsonIgnore
    public PageRequest getPageRequest() {
        val orderBys = CollectionUtils.isEmpty(getOrders()) ? new ArrayList<Sort.Order>() :
                getOrders().stream().filter(t -> StringUtils.hasText(t.getColumn())).map(o -> new Sort.Order(
                        o.isAsc() ? Sort.Direction.ASC : Sort.Direction.DESC,
                        o.getColumn()
                )).collect(Collectors.toList());

        return PageRequest.of(getCurrent(), getSize(), Sort.by(orderBys));
    }

    /**
     * 单表查询,排序方法
     *
     * @param query
     * @param entityPathBase 实体对象
     */
    @JsonIgnore
    public void fillOrders(JPAQuery<?> query, EntityPathBase<?> entityPathBase) {
        val pageRequest = getPageRequest();
        val orderbyExpr = new PathBuilder<>(entityPathBase.getClass(),
                entityPathBase.getMetadata(), PathBuilderValidator.FIELDS);
        pageRequest.getSort().forEach(s -> query.orderBy(
                new OrderSpecifier(
                        s.isAscending() ? Order.ASC : Order.DESC,
                        orderbyExpr.get(s.getProperty())
                )
        ));
    }

    /**
     * 多表关联查询，排序方法。要求：排序字段格式需为 “实体对象名称.字段名称”
     *
     * @param query
     */
    @JsonIgnore
    public void fillOrders(JPAQuery<?> query) {
        val pageRequest = getPageRequest();
        pageRequest.getSort().forEach(s -> {
            val sects = s.getProperty().split("\\.");
            if (sects.length > 1) {
                val orderbyExpr = new PathBuilder<>(Object.class, sects[0]);
                query.orderBy(new OrderSpecifier(s.isAscending() ?
                        Order.ASC : Order.DESC, orderbyExpr.get(sects[1])));
            } else {
                throw new BusinessException(ApiCode.PARAMETER_PARSE_EXCEPTION, "排序字段需要指定所属hql的实体对象，对象名称.字段名称");
            }
        });
    }

    @JsonIgnore
    public void setPaging(JPAQuery<?> query) {
        query.offset((long) getCurrent() * getSize());
        query.limit(getSize());
    }
}
